/*  Copyright (C) 2010-2024 Institute of Aerospace Systems, RWTH Aachen University - All rights reserved.
    This file is part of UNICADO.

    UNICADO is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    UNICADO is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with UNICADO.  If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef CALCULATEPOLAR_SRC_TAW_HLFCDATA_H_
#define CALCULATEPOLAR_SRC_TAW_HLFCDATA_H_

#include <atmosphere/atmosphere.h>
#include <standardFiles/typedefs.h>
#include <aixml/endnode.h>

#include <string>
#include <unordered_map>
#include <vector>
#include <map>

/** \brief Class contains all properties of calculated aircraft objects
*/
class HLFCData {
 public:
    /* Typedefs */
    /** \brief Constructor of aircraft class
     *  \param &mySettings Reference to calculatePolarSettings object
     */
    explicit HLFCData(const node& acftXML);
    /** \brief Virtual destructor of aircraft class
     */
    virtual ~HLFCData() {}
    /* !!! WARNING: All EndnodeReadOnly Values are converted automatically to SI-Units/RADIAN when read in */

    EndnodeReadOnly<double> bestCruiseCL;
    EndnodeReadOnly<double> initialCruiseMachNumber;
    EndnodeReadOnly<std::string> engineType;

    EndnodeReadOnly<double>designCoGX;
    EndnodeReadOnly<double>designCoGY;
    EndnodeReadOnly<double>designCoGZ;
    EndnodeReadOnly<double>forwardCoGX;
    EndnodeReadOnly<double>forwardCoGY;
    EndnodeReadOnly<double>forwardCoGZ;
    EndnodeReadOnly<double>aftCoGX;
    EndnodeReadOnly<double>aftCoGY;
    EndnodeReadOnly<double>aftCoGZ;
    Point designCoG;              /**< Center of gravity coordinates */
    Point forwardCoG;       /**< Forward position of center of gravity */
    Point aftCoG;           /**< Average flight time position of center of gravity */
    Point cruiseTrimRefCoG; /**< Cruise reference center of gravity position */
    std::unordered_map <std::string, Point> CoGPositions;    /**< Map connecting CoG names with points */
    size_t numberDevices;
    struct wingDevice {
        std::string type;
        double maxPositiveDeflection;
        double maxNegativeDeflection;
        double innerRelSpanPosition;
        double innerRelFwdChordPosition;
        double innerRelAftChordPosition;
        double outerRelSpanPosition;
        double outerRelFwdChordPosition;
        double outerRelAftChordPosition;
    };
    std::vector<wingDevice> wingDevices;
};

#endif  // CALCULATEPOLAR_SRC_TAW_HLFCDATA_H_
