/**
 * \file calculateEmissions_schaefer.h
 * \author katrin.bistreck@tuhh.de
 * \brief Strategy to calculate missions according to Schäfer(2011)
 * \version 0.1
 * \date 2023-11-25
 *
 * @copyright Copyright (c) 2023
 *
 */
#ifndef ECOLOGICAL_ASSESSMENT_SRC_STANDARD_STRATEGY_EMISSION_CALCULATION_LIFE_CYCLE_EMISSIONS_LCA_SCHAEFER_CALCULATEEMISSIONS_SCHAEFER_H_
#define ECOLOGICAL_ASSESSMENT_SRC_STANDARD_STRATEGY_EMISSION_CALCULATION_LIFE_CYCLE_EMISSIONS_LCA_SCHAEFER_CALCULATEEMISSIONS_SCHAEFER_H_

#include <memory>
#include <vector>
#include <string>
#include <moduleBasics/strategySelector.h>
#include <moduleBasics/report.h>
#include <moduleBasics/plot.h>
#include <moduleBasics/runtimeIO.h>
#include <aixml/node.h>
#include "schaeferIOData.h"
#include "../../ecoDatabase.h"
#include "production.h"
#include "operation.h"
#include "endOfLife.h"
#include "development.h"

/** \class LifeCycleEmissionsSchaefer
 * \brief Class for emission calculation according to K. Schaefer
 *
 */
class LifeCycleEmissionsSchaefer {
 public:
   /** \brief Constructor of class LifeCycleEmissionsSchaefer
    */
    LifeCycleEmissionsSchaefer() {}
    /** \brief Destructor of class LifeCycleEmissionsSchaefer */
    ~LifeCycleEmissionsSchaefer() = default;

    /** \brief Runs life cycle emission calcualtion according to Schaefer 2011*/
    void run(const std::shared_ptr<RuntimeIO> &rtIO, std::shared_ptr<node> ecoAssXML);

    std::shared_ptr<SchaeferIOData> schaeferIOData_; /**< IOData object*/
    Development theDevelopment;/**< Object contains data for the entire certification process (i.e. for the entire aircraft program) */
    Production theProduction;/**< Object of class Productionthat contains production data */
    Operation theOperation;/**< Object contains operation data */
    EndOfLife theEndOfLife;/**< Object contains end of life data */
};

#endif //ECOLOGICAL_ASSESSMENT_SRC_STANDARD_STRATEGY_EMISSION_CALCULATION_LIFE_CYCLE_EMISSIONS_LCA_SCHAEFER_CALCULATEEMISSIONS_SCHAEFER_H_
