# Getting started {#getting-started}
Welcome to the Empennage Design Tool! This section will guide you through the initial steps to access and begin using the tool.
This guide gives you a step-by-step overview of the parameters which affects the basic module behavior.

## Method selection
The main method selection, _which_ empennage shall be designed comes from the _Aircraft Exchange File_. This is defined in the Block `requirements_and_specification` of the _Aircraft Exchange File_.

Here you have a main element which will affect the empennage design inside `design_specification/configuration`:
- `configuration_type`: This defines the aircraft configuration which the wing is build for
  - `tube_and_wing`
  - `blended_wing_body`

- `empennage_definition`: This defines what type of empennage shall be designed
  - for _Tube and Wing_: `conventional` or `t_tail`
  - for _Blended Wing Body_: `vertical_tails`


The configuration file of the Empennage Design tool `empennage\_design_conf.xml`, gives you then more specified parameters to chose which will tailor the empennage to your desire in the `program_settings` Block.

The file comes with mode selectors and associated parameters to set which can vary.

Parameters to chose:
- `design_mode`:
  - `mode_0: design`: Designs an empennage from scratch
  - `mode_1: redesign`: Redesigns an existing empennage (not implemented - planned in a future release)

As an example selection:
- `configuration_type` &rarr; `tube_and_wing`
- `empennage_type` &rarr; `conventional`

This selects a conventional tail for a tube and wing configuration.
<pre class="mermaid">
graph LR;
  A[Empennage Design] ==> B[Tube and Wing];
  B==>C[Conventional];
  B-->E[T-Tail];
  A-->D[Blended Wing body];
  D-->F[Vertical Tails];
  style B stroke-width:4px
  style C stroke:#0f0, stroke-width:4px
</pre>


Each `empennage_type` will have it's own block to chose parameters from.
<dl class="section todo">
<dt>Note</dt>
<dd>For default values or ranges, you should check the description of the parameters or the allowed ranges inside the configuration file</dd>
</dl>

<dl class="section invariant">
<dt>Tip</dt>
<dd>If you are missing some of the terms in here - take a look at [basic concepts](basic-concepts.md).</dd>
</dl>

## Configuration parameters &rarr; General
In this section you find parameters for an empennage. To keep it simple, a so called ID `tail_element` is part of each existing configuration. It defines basic parts for a classic volume coefficient method (low-fidelity).
### The Tail Elements parameters (ID Element)
Each tail element has the following parameter which may differ from empennage type
- `name`: Name of the element
- `parameter`:
  - `offset`: Offset in multiple directions (differs for empennage type)
  - `volume_coefficent`: Associated volume coefficient, if coefficient is set to 0 automatic values are used based on empirical data
  - `factor_aspect_ratio`: A factor on how to scale the aspect ratio of a part of the empennage according to the wing aspect ratio
  - `factor_taper_ratio`: A factor on how to scale the taper ratio of a part of the empennage according to the wing aspect ratio
  - `delta_sweep`: Additional sweep to a part of the empennage according to the wing sweep
- `profiles`: Tail profile used (root and tip)
  - `profile`: Tail profile name - ID Element
- `spars`: Spar for a tail
  - `spar`: Spar Element - ID Element
    - `param: name`: Set spar name (e.g. front spar, rear spar etc.)
    - `param: position`: Set position parameters like chordwise and spanwise position for inner and outer dimension of a spar
- `control_devices`: Control devices for a tail
  - `control_device`: Control device Element - ID Element
    - `param: type`: Sets type of control device (e.g. aileron, rudder, elevator...)
    - `param: deflection`: Set positive and negative deflection limits
    - `param: position`: Set position parameters like chordwise and spanwise position for inner and outer dimension of a control device

### Tube and Wing: The Conventional Tail (low fidelity &rarr Volume Coefficient Method)
For a conventional tail, two tail elements are required! Here specific parts should be mentioned:

- `tail_element ID="0"`:
  - `name`: vertical_stabilizer
  - `offset`: Offset of the vertical stabilizer
    - `rear_x_offset`: Set offset to between vertical stabilizer at root chord trailing edge to the fuselage end
    - `centerline_y_offset`: Set offset from the centerline of the fuselage in y direction - should be zero
    - `centerline_z_offset`: Set offset from the centerline of the fuselage in z direction - should be zero
- `tail_element ID="1"`:
  - `name`: horizontal_stabilizer
  - `offset`: Offset of the horizontal stabilizer
    - `rear_x_offset`: Set offset to between horizontal stabilizer at root chord trailing edge to the fuselage end
    - `centerline_y_offset`: Set offset from the centerline of the fuselage in y direction - should be zero
    - `centerline_z_offset`: Set offset from the centerline of the fuselage in z direction - should be zero

<dl class="section todo">
<dt>Note</dt>
<dd>Control surfaces should be named here according to its usage e.g. horizontal stabilizer has an elevator and vertical stabilizer has a rudder.</dd>
</dl>

<dl class="section bug">
<dt>Important</dt>
<dd>The user must be careful! You can choose values in a certain range, however always keep in mind _with great power comes great responsibility!_</dd>
</dl>

### Tube and Wing: The T-Tail (low fidelity &rarr Volume Coefficient Method)
For a T-tail, two tail elements are required! Here specific parts should be mentioned:

- `tail_element ID="0"`:
  - `name`: vertical_stabilizer
  - `offset`: Offset of the vertical stabilizer
    - `param: rear_x_offset`: Set offset between vertical stabilizer at root chord trailing edge to the fuselage end
    - `param: centerline_y_offset`: Set offset from the centerline of the fuselage in y direction - should be zero
    - `param: centerline_z_offset`: Set offset from the centerline of the fuselage in z direction - should be zero
- `tail_element ID="1"`:
  - `name`: horizontal_stabilizer
  - `offset`: Offset of the horizontal stabilizer trailing
    - `param: rear_x_offset`: Set offset between horizontal stabilizer at root chord trailing edge to the tip chord of the vertical stabilizer trailing edge.
    - `param: centerline_y_offset`: Set offset from the centerline of the fuselage in y direction - should be zero
    - `param: centerline_z_offset`: Set offset from the centerline of the fuselage in z direction - should be zero

<dl class="section todo">
<dt>Note</dt>
<dd>Control surfaces should be named here according to its usage e.g. horizontal stabilizer has an elevator and vertical stabilizer has a rudder.</dd>
</dl>

<dl class="section bug">
<dt>Important</dt>
<dd>The user must be careful! You can choose values in a certain range, however always keep in mind _with great power comes great responsibility!_</dd>
</dl>


### Blended Wing Body: The Vertical Tails method (low fidelity &rarr Volume Coefficient Method)
For a blended wing body, only one tail element is required! This method is experimental and will only be applyable on the center body, so no checking of values is active to give you freedom to design!
It will create a tail and it's symmetric partner mirrored on the centerline of the Blended Wing Body. So keep in mind to keep the `offset` section correctly.
- `offset`:
  - `param: rear_x_offset`: Set offset between vertical stabilizer at root chord trailing edge to the end of the fuselage (center body wing) at specified y offset.
  - `param: centerline_y_offset`: Set offset from the centerline of the fuselage in y direction - should be NONE zero
  - `param: centerline_z_offset`: Set offset from the centerline of the fuselage in z direction - should be zero

A copied version will be generated automatically.

<dl class="section warning">
<dt>Warning</dt>
<dd>Do not create a second element on the other side, it will be mirrored automatically.</dd>
</dl>

<dl class="section bug">
<dt>Important</dt>
<dd>The user must be careful! You can choose values in a certain range, however always keep in mind _with great power comes great responsibility!_</dd>
</dl>


### Mass Calculation methods - general
_Mass Calculation Methods_
  - `mass`: How to calculate the mass methods
    - `mode_0: flops`: Calculate the empennage mass according to FLOPS (_NASA Flight Optimization System_)
    -
## Additional configurations
Additionally, one has to define the common airfoil data paths inside the configuration file:
- `common_airfoil_data_paths`: Defines the path, where to look for airfoils - normally a database

## Additional information and requirements
The methods in the empennage design tool also require additional information on the wing and the fuselage from the requirements and specification block of the _Aircraft Exchange File_.

<dl class="section bug">
<dt>Important</dt>
<dd>Keep in mind that the _empennage\_design_ tool generates an empennage as a part of an aircraft. This lets it rely on specific values, e.g. for defining the area inside the fuselage etc. This leads to mandatory items at this point:
- A specified fuselage - here length and width and height are necessary to determine wing geometry and wing position
- Initial Maximum Takeoff Mass (MTOM) - for determination of the wing area necessary based on the wing loading (only if method is selected)</dd>
</dl>

Please keep in mind, that the module is still in beta phase and you can gratefully contribute to the

## Next Steps
The next step is to run the _empennage\_design_ tool. So let's get your wings from [Design your first empennage](dfe.md)
