/**
 * \file volumeCoefficientMethod.h
 * \author Christopher Ruwisch (christopher.ruwisch@tu-berlin.de)
 * \brief Volume coefficient method
 * \version 0.1
 * \date 2023-10-27
 *
 * @copyright Copyright (c) 2023
 *
 */
#ifndef VOLUME_COEFFICIENT_METHOD_H_
#define VOLUME_COEFFICIENT_METHOD_H_

#include <aircraftGeometry2/geometry/factory.h>
#include <aircraftGeometry2/io/dat.h>
#include <aircraftGeometry2/processing/transform.h>

#include <Eigen/Dense>
#include <tuple>

class VolumeCoefficientMethod {
 public:
  VolumeCoefficientMethod() = default;

  void compute_geometry(int number_of_tails, double volume_coefficient, double sweep, double taper_ratio,
                        double aspect_ratio, double reference_area, double reference_length, double fuselage_length,
                        geom2::Point_3& reference_neutral_point, geom2::Point_3& offset_position,
                        geom2::Direction_3 orientation, bool symmetric);
  void compute_geometry(int number_of_tails, double volume_coefficient, double sweep, double taper_ratio,
                        double root_chord, double wing_area, double wing_span,
                        geom2::Point_3& wing_neutral_point_position, geom2::Point_3& reference_position,
                        bool symmetric);

  geom2::MultisectionSurface<geom2::AirfoilSection> get_design(geom2::AirfoilSection root_profile,
                                                               geom2::AirfoilSection tip_profile,
                                                               const double dihedral);

  double root_chord{0.};
  double tip_chord{0.};
  double span{0.};
  double sweep{0.};
  int span_multiplier{2};

  geom2::Point_3 origin{geom2::Point_3(0., 0., 0.)};
  geom2::Direction_3 orientation{geom2::Direction_3(0., 0., 1.)};
  geom2::MultisectionSurface<geom2::AirfoilSection> surface;
};

#endif  // VOLUME_COEFFICIENT_METHOD_H_