/*  Copyright (C) 2011-2022 Institute of Aerospace Systems, RWTH Aachen University - All rights reserved.
    This file is part of UNICADO.

    UNICADO is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    UNICADO is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with UNICADO.  If not, see <http://www.gnu.org/licenses/>.
*/
/**
 * \file initialSizing.h
 * \author Sara Hijazi
 * \brief Base module for initial sizing
 * \version 0.1
 * \date 2024-02-28
 *
 * @copyright Copyright (c) 2023
 *
 */
#ifndef INITIALSIZING_SRC_INITIALSIZING_H_
#define INITIALSIZING_SRC_INITIALSIZING_H_

#include <vector>
#include <string>

#include <moduleBasics/module.h>
#include <moduleBasics/strategySelector.h>

/**
 * \brief systemsDesign module for sizing systems
 * 
 */
class initialSizing : public Module {
 public:
    initialSizing(const int argc, char *argv[], const std::string &toolName, const std::string &toolVersion);
    ~initialSizing() = default;

    void initialize() override { strategy_.initializeStrategy(); };
    void run() override { strategy_.runStrategy(); };
    void update() override { strategy_.updateStrategy(); };
    void report() override { strategy_.reportStrategy(); };
    void save() override { strategy_.saveStrategy(); aixml::saveDocument(rtIO_->acxml, rtIO_->ownToolLevel);};

 private:
    // StrategySelector<ModuleConfig> typeSelector_;
    // ModuleConfig moduleConfig_;
    std::vector<std::string> route;
    strategyaccess routing_(const std::vector<std::string> &route);
    StrategySelector strategy_;
};

#endif  // INITIALSIZING_SRC_INITIALSIZING_H_
