# Import own modules.
from src.wing_mounted.empirical.landing_gear_design_tu_berlin.general.aicraft_classification_number.flexible_pavement.storeflexcurvefits import store_flex_curve_fits  # noPep8 e501


def initialize_acn_flex_parameter(runtime_output):
    """ This function initialized the acn parameter in accordance to ICAO COMFAA tool.

    :return dict input_dict_acn_flex: Dict containing initial parameter for acn estimation
            dict dict_constants: Dict contains constants
    """
    # initialize dictionary with default values for acn flex estimation
    input_dict_acn_flex = {'select_new_alpha_from_curve': bool(),
                           'StandardCoverages': int(10000),
                           'coverages': int(0),
                           'FlexDesignESWL': 0.0,
                           'U': [0.0],
                           'V': [0.0],
                           'SSS': '',
                           'X': [0.0],
                           'Y': [0.0],
                           'Rad': [],
                           'RAD2': [],
                           'PR': [0.0],
                           'PRS': [0.0],
                           'XG': [],
                           'YG': [],
                           'S': [],
                           'Z': [0.0, 0.0],
                           'Z2': [0.0, 0.0],
                           'XLOC': [[0.0] * 6 for _ in range(31)],
                           'YLOC': [[0.0] * 6 for _ in range(31)],
                           'SD': [[0.0] * 6 for _ in range(31)],
                           'C': [0.0] * 5,
                           'ESWL': [],
                           'CBR': 0.0,
                           'SN2': [0.0],
                           'CS': [] * 50,
                           'KTITLE': '',
                           'Continue': 0,
                           'NW': 0,
                           'NWMax': 24,
                           'I': 0,
                           'J': 0,
                           'K': 0,
                           'L': 0,
                           'M': 0,
                           'XK': 0.0,
                           'YK': 0.0,
                           'XMax': 0.0,
                           'YMax': 0.0,
                           'GX': 0.0,
                           'GY': 0.0,
                           'DGX': 0.0,
                           'DGY': 0.0,
                           'KX': 0,
                           'KY': 0,
                           'IPR': 0,
                           'IPRS': 0,
                           'AMASS': 0.0,
                           'PRSW': 0.0,
                           'PMMG': [0.0, 0.0],
                           'AMLG': 0.0,
                           'InputAlpha': 0.0,
                           'AlternateAlpha': 0.0,
                           'WT': 0.0,
                           'TLMG': 0.0,
                           'TLSMG': 0.0,
                           'WN': 0.0,
                           'TLSW': 0.0,
                           'ARESW': 0.0,
                           'RESW': 0.0,
                           'PESW': 0.0,
                           'CAREA': 0.0,
                           'RESW2': 0.0,
                           'DZ': 0.0,
                           'NAL': 0,
                           'DPE': 0.0,
                           'ICBR': 1,
                           'KZ': 2,
                           'PID': 0.0,
                           'PHI': 0.0,
                           'SINE': 0.0,
                           'YI': 0.0,
                           'XJ': 0.0,
                           'Z2K': 0.0,
                           'SS': 0.0,
                           'RADL': 0.0,
                           'RAD2L': 0.0,
                           'PRL': 0.0,
                           'SJIK': 0.0,
                           'XLG': 0.0,
                           'R': 0.0,
                           'R2': 0.0,
                           'RC': 0.0,
                           'YLG': 0.0,
                           'SAR': 0.0,
                           'ERP': 0.0,
                           'ERP2': 0.0,
                           'ERM': 0.0,
                           'ERM2': 0.0,
                           'DW2': 0.0,
                           'DW1': 0.0,
                           'DW3': 0.0,
                           'AC': 0.0,
                           'SPA': 0.0,
                           'SPA2': 0.0,
                           'SSA': 0.0,
                           'SSA2': 0.0,
                           'IX': 0,
                           'IY': 0,
                           'IZ': 0,
                           'IXM': 0,
                           'IYM': 0,
                           'EMAX': 0.0,
                           'SRAREA': 0.0,
                           'KS': 1,
                           'V1': 0.0,
                           'UL': 0.0,
                           'U1': 0.0,
                           'Mode': 0,
                           'ACN': 0.0,
                           'Temp': 0.0,
                           'LengthConvert': 0.0,
                           'PressConvert': 0.0,
                           'WeightConvert': 0.0,
                           'SCBR': [3, 6, 10, 15],
                           'B': [0.0] * 7,
                           'NCC': [10000],
                           'TA': [],
                           'ITER': True,
                           'ITCT': 0,
                           'FCTN': 0.0,
                           'TRGT': 0.0,
                           'PESWL': [],
                           'PCBR': [],
                           'PZ': [],
                           'PACN': [],
                           'CBRThickness': [],
                           'AlphaFactor': [],
                           'ZERO': 2E-20,
                           'X222': 0,
                           'X333': 0,
                           'Y111': 0,
                           'Y222': 0,
                           'Y333': 0
                           }

    # call function to generate curve fitting data points according to ACN/PCN methode
    u, v = store_flex_curve_fits()
    input_dict_acn_flex['U'] = u
    input_dict_acn_flex['V'] = v

    # initialize dictionary with constants
    dict_constants = {'inch_to_cm': float(2.54),
                      'mpa_to_psi': 145.0377438,
                      'kg_to_lbs': 2.2046225,
                      'pi': 3.1415926535898,
                      'g0': 9.80665
                      }

    runtime_output.debug('set_acn_flex_input_parameter successfully executed!')

    return input_dict_acn_flex, dict_constants
