def convergence_check(landing_gear_description, convergence_parameter, runtime_output, convergence_flag, i):
    """  Module checks the convergence of landing gear design an prepared the log-file and console prints.

    :param dict landing_gear_description: Dict containing parameter and values of current landing gear estimation
    :param dict convergence_parameter: Dictionary containing the convergence parameter
    :param logging.Logger runtime_output: Logging object used for capturing log messages in the module
    :param bool convergence_flag: Boolean containing the current status of convergence
    :param int i: Integer contains the current number of landing gear iterations
    :return: dict convergence_parameter: Dictionary containing the convergence parameter
             bool convergence_flag: Boolean containing the current status of convergence
    """
    
    # estimate nose gear residual
    residual_nose_gear_position_in_x = \
        round(abs(1 - convergence_parameter['nose_gear_position_in_x']
                    / landing_gear_description['landing_gear_positions']['nose_gear_x_position']), 4)
    if residual_nose_gear_position_in_x <= convergence_parameter['convergence_criteria']:
        status_residual_nose_gear_position_in_x = True
    else:
        status_residual_nose_gear_position_in_x = False
    convergence_parameter['nose_gear_position_in_x'] = landing_gear_description['landing_gear_positions']['nose_gear_x_position']

    residual_nose_gear_strut_length = \
        round(abs(1 - convergence_parameter['nose_gear_strut_length']
                    / landing_gear_description['nose_gear_description']['nose_gear_arrangement']
                                            ['nose_gear_strut_length']), 4)
    if residual_nose_gear_strut_length <= convergence_parameter['convergence_criteria']:
        status_residual_nose_gear_strut_length = True
    else:
        status_residual_nose_gear_strut_length = False
    convergence_parameter['nose_gear_strut_length'] = \
        landing_gear_description['nose_gear_description']['nose_gear_arrangement']['nose_gear_strut_length']

    # estimate main gear residual
    residual_main_gear_position_in_x = \
        round(abs(1 - convergence_parameter['main_gear_position_in_x']
                    / landing_gear_description['landing_gear_positions']['main_gear_x_position']), 4)
    if residual_main_gear_position_in_x <= convergence_parameter['convergence_criteria']:
        status_residual_main_gear_position_in_x = True
    else:
        status_residual_main_gear_position_in_x = False
    convergence_parameter['main_gear_position_in_x'] = landing_gear_description['landing_gear_positions']['main_gear_x_position']

    residual_main_gear_strut_length = \
        round(abs(1 - convergence_parameter['main_gear_strut_length']
                    / landing_gear_description['main_gear_description']['main_gear_arrangement']
                                            ['main_gear_outer_strut_length']), 4)
    if residual_main_gear_strut_length <= convergence_parameter['convergence_criteria']:
        status_residual_main_gear_strut_length = True
    else:
        status_residual_main_gear_strut_length = False
    convergence_parameter['main_gear_strut_length'] = \
        landing_gear_description['main_gear_description']['main_gear_arrangement']['main_gear_outer_strut_length']

    residual_main_gear_outer_strut_y_position = \
        round(abs(1 - convergence_parameter['main_gear_outer_strut_y_position']
                    / landing_gear_description['landing_gear_positions']['main_gear_outer_strut_y_position']), 4)
    if residual_main_gear_outer_strut_y_position <= convergence_parameter['convergence_criteria']:
        status_residual_main_gear_outer_strut_y_position = True
    else:
        status_residual_main_gear_outer_strut_y_position = False
    convergence_parameter['main_gear_outer_strut_y_position'] = \
        landing_gear_description['landing_gear_positions']['main_gear_outer_strut_y_position']

    # Nose gear results.
    runtime_output.print('----- Nose gear results of current loop -----')
    runtime_output.print('Nose gear x-position is: ' + str(convergence_parameter['nose_gear_position_in_x']) + ' meter behind reference point.')  # noPep8 e501
    runtime_output.print('Nose gear y-position is: ' + str(landing_gear_description['landing_gear_positions']['nose_gear_strut_y_position']) + ' meter from reference center line.')  # noPep8 e501
    runtime_output.print('Nose gear z-position is: ' + str(landing_gear_description['landing_gear_positions']['nose_gear_z_position']) + ' meter below reference center line.')  # noPep8 e501
    runtime_output.print('Number of nose gear struts is: ' + str(landing_gear_description['nose_gear_description']['nose_gear_arrangement']['number_of_nose_gear_struts']) + '.')  # noPep8 e501
    runtime_output.print('Nose gear strut length is: ' + str(landing_gear_description['nose_gear_description']['nose_gear_arrangement']['nose_gear_strut_length']) + ' meter.')  # noPep8 e501
    runtime_output.print('Number of nose gear axis per strut is: ' + str(landing_gear_description['nose_gear_description']['nose_gear_arrangement']['number_of_nose_gear_axis_per_strut']) + '.')  # noPep8 e501
    runtime_output.print('Number of nose gear tires per strut is: ' + str(landing_gear_description['nose_gear_description']['nose_gear_arrangement']['number_of_nose_gear_tires_per_strut']) + '.')  # noPep8 e501
    runtime_output.print('Nose gear tires design load is: ' + str(landing_gear_description['nose_gear_description']['nose_gear_arrangement']['nose_gear_tire_design_load']) + ' pound.')  # noPep8 e501
    runtime_output.print('Selected nose gear tire type is: ' + str(next(iter(landing_gear_description['nose_gear_description']['nose_gear_tires']))) + '.')  # noPep8 e501
    # Main gear results.
    runtime_output.print('----- Main gear results of current loop -----')
    runtime_output.print('Outer main gear x-position is: ' + str(convergence_parameter['main_gear_position_in_x']) + ' meter behind reference point.')  # noPep8 e501
    runtime_output.print('Outer main gear strut y-position is: ' + str(convergence_parameter['main_gear_outer_strut_y_position']) + ' meter from reference center line.')  # noPep8 e501
    runtime_output.print('Outer main gear strut z-position is: ' + str(landing_gear_description['landing_gear_positions']['main_gear_z_position_outer_strut']) + ' meter below reference center line.')  # noPep8 e501
    runtime_output.print('Number of outer main gear struts is: ' + str(landing_gear_description['main_gear_description']['main_gear_arrangement']['number_of_main_gear_outer_struts']) + '.')  # noPep8 e501
    runtime_output.print('Outer main gear strut length is: ' + str(landing_gear_description['main_gear_description']['main_gear_arrangement']['main_gear_outer_strut_length']) + ' meter.')  # noPep8 e501
    runtime_output.print('Number of main gear axis per outer strut is: ' + str(landing_gear_description['main_gear_description']['main_gear_arrangement']['number_of_main_gear_axis_per_outer_strut']) + '.')  # noPep8 e501
    runtime_output.print('Number of main gear tires per outer strut is: ' + str(landing_gear_description['main_gear_description']['main_gear_arrangement']['number_of_main_gear_tires_per_outer_strut']) + '.')  # noPep8 e501
    if landing_gear_description['main_gear_description']['main_gear_arrangement']['number_of_main_gear_struts'] > 2:
        runtime_output.print('Inner main gear x-position is: ' + str(convergence_parameter['main_gear_position_in_x']) + ' meter behind reference point.')  # noPep8 e501
        runtime_output.print('Inner main gear strut y-position is: ' + str(landing_gear_description['landing_gear_positions']['main_gear_inner_strut_y_position']) + ' meter from reference center line.')  # noPep8 e501
        runtime_output.print('Inner main gear strut z-position is: ' + str(landing_gear_description['landing_gear_positions']['main_gear_z_position_inner_strut']) + ' meter below reference center line.')  # noPep8 e501
        runtime_output.print('Number of inner main gear struts is: ' + str(landing_gear_description['main_gear_description']['main_gear_arrangement']['number_of_main_gear_inner_struts']) + '.')  # noPep8 e501
        runtime_output.print('Inner main gear strut length is: ' + str(landing_gear_description['main_gear_description']['main_gear_arrangement']['main_gear_inner_strut_length']) + ' meter.')  # noPep8 e501
        runtime_output.print('Number of main gear axis per inner strut is: ' + str(landing_gear_description['main_gear_description']['main_gear_arrangement']['number_of_main_gear_axis_per_inner_strut']) + '.')  # noPep8 e501
        runtime_output.print('Number of main gear tires per inner strut is: ' + str(landing_gear_description['main_gear_description']['main_gear_arrangement']['number_of_main_gear_tires_per_inner_strut']) + '.')  # noPep8 e501
    runtime_output.print('Main gear tires design load is: ' + str(landing_gear_description['main_gear_description']['main_gear_arrangement']['main_gear_tire_design_load']) + ' pound.')  # noPep8 e501
    runtime_output.print('Selected main gear tire type is: ' + str(next(iter(landing_gear_description['main_gear_description']['main_gear_tires']))) + '.\n')  # noPep8 e501

    # check if the landing gear limitation flag is true
    #  -> if true: -> check convergence -> otherwise restart landing gear estimation
    if landing_gear_description['landing_gear_limitations']['limitation_flag']:
        if status_residual_nose_gear_position_in_x and status_residual_nose_gear_strut_length \
                and status_residual_main_gear_position_in_x and status_residual_main_gear_strut_length \
                and status_residual_main_gear_outer_strut_y_position:
            convergence_flag = True
            runtime_output.print('Landing gear design successful after ' + str(i) + ' iterations!')
    
    # debug print
    runtime_output.debug('convergence_check successfully executed!')
    
    return convergence_parameter, convergence_flag
