/**
 * \file mission_analysis.cpp
 * \author Gerrit Pauls (gerrit.pauls@tuhh.de)
 * \brief
 * \version 0.1
 * \date 2024-08-30
 *
 * @copyright Copyright (c) 2024
 *
 */
#include <memory>
#include <map>
#include <string>
#include <vector>

#include "mission_analysis.h"
#include "standard_mission/standard_mission/standard_mission.h"

/**
 * @brief Construct a new mission_analysis:: mission_analysis object
 * 
 * @param argc argument count
 * @param argv vector of C++ style argument strings
 * @param toolName entry from toolinfo.h
 * @param toolVersion entry from toolinfo.h
 */
mission_analysis::mission_analysis(const int argc, char *argv[], const std::string &toolName, const std::string &toolVersion)
        : Module(argc, argv, toolName, toolVersion) {
    std::string method = (EndnodeReadOnly<std::string>("program_settings/mode/mission_methods/fidelity_level").read(rtIO_->moduleConfig).value());
    std::string mission_type(EndnodeReadOnly<std::string>("program_settings/mode/mission_methods/mission_type").read(rtIO_->moduleConfig).value());
    // if (this->has_requirements_to_be_checked(mission_type)) { // Run strategy with requirements check
    //     route_ = {method, "requirements_check"};
    //     missionStrategy_.setStrategy(missionSelection_(route_)(rtIO_));
    //     missionStrategy_.initializeStrategy();
    //     missionStrategy_.runStrategy();
    //     missionStrategy_.updateStrategy();
    //     missionStrategy_.reportStrategy();
    // } //TODO(Gerrit): Kann das nicht auch weg, wenn man es danach einfach per selector machen kann?
    route_ = {method, mission_type};
    missionStrategy_.setStrategy(missionSelection_(route_)(rtIO_));
}

strategyaccess mission_analysis::missionSelection_(const std::vector<std::string> &route) {
    /* Routing table */
    std::map<std::string, std::map<std::string, strategyaccess>> table = {
    {"low", std::map<std::string, strategyaccess>{
            {"design_mission",        [](const std::shared_ptr<RuntimeIO>& arg) { return std::make_unique<design_mission::standard_mission>(arg); }},
            {"study_mission",         [](const std::shared_ptr<RuntimeIO>& arg) { return std::make_unique<study_mission::standard_mission>(arg); }},
            {"requirements_mission",  [](const std::shared_ptr<RuntimeIO>& arg) { return std::make_unique<requirements_mission::standard_mission>(arg); }}
        }
    }
  };
  return table[route.at(0)][route.at(1)];
}

/* Check need for requirement check */
bool mission_analysis::has_requirements_to_be_checked(const std::string& mission_type) {
    /* Open aircraft exchange file for requirement checks */
    std::string subpath("analysis/requirement_compliance/top_level_aircraft_requirements");
    if (EndnodeReadOnly<bool>("program_settings/mode/requirement_check/enable").read(rtIO_->moduleConfig).value() && mission_type == "study_mission" &&
        (EndnodeReadOnly<bool>("/program_settings/mode/requirement_check/force_requirement_check").read(rtIO_->moduleConfig).value() ||
        !EndnodeReadOnly<bool>(subpath + "/initial_cruise_altitude/checked").read(rtIO_->acxml).value() ||
        !EndnodeReadOnly<bool>(subpath + "/maximum_operating_altitude/checked").read(rtIO_->acxml).value() ||
        !EndnodeReadOnly<bool>(subpath + "/maximum_altitude_one_engine_inoperative/checked").read(rtIO_->acxml).value() ||
        !EndnodeReadOnly<bool>(subpath + "/initial_cruise_mach_number/checked").read(rtIO_->acxml).value() ||
        !EndnodeReadOnly<bool>(subpath + "/design_time_to_climb/checked").read(rtIO_->acxml).value())) {
        return true;
    }
    return false;
}
