/*  Copyright (C) 2012-2022 Institute of Aerospace Systems, RWTH Aachen University - All rights reserved.
    This file is part of UNICADO.

    UNICADO is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    UNICADO is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with UNICADO.  If not, see <http://www.gnu.org/licenses/>.
*/
#ifndef performance_assessment_SRC_TAW_DEFAULTMETHODS_SARPERFORMANCE_LOW_FIDELITY_SARPERFORMANCE_H_
#define performance_assessment_SRC_TAW_DEFAULTMETHODS_SARPERFORMANCE_LOW_FIDELITY_SARPERFORMANCE_H_

#include <moduleBasics/module.h>

#include <vector>
#include <string>
#include <memory>

#include "../abstractSARPerformance.h"
#include "../../flightEnvelopes/abstractFlightEnvelopes.h"
#include "../../aircraft.h"


// class aircraft;
// class flightEnvelopes;

using std::string;
using std::vector;

namespace low {

/**\class SARPerformance global class that contains informations about the specific air range (SAR)
*
*/
class SARPerformance : public abstractSARPerformance{
 public:


    /**\brief Function to calculate the flight parameters for the specific air range
    *\param theEnvelopes flightEnvelopes object
    */
    void doSARCalculation(std::shared_ptr<abstractFlightEnvelopes> theEnvelopes);

    /**\brief Function calculates the specific air range
    *\param mass Aircraft mass (kg)
    *\param alt Aircraft altitude (m)
    *\param rating Engine rating (-)
    *\param configuration Flap configuration (-)
    *\return Specific air range (m/kg)
    */
    double calculateSAR(double mass, double alt, double mach, string rating, string configuration);

    /**\brief Constructor SARPerformance
    *\param theAircraft Address to the aircraft object
    */
    explicit SARPerformance(std::shared_ptr<aircraft> theAircraft);

    /**\brief Destructor SARPerformance
    *
    */
    virtual ~SARPerformance();

 private:
    std::shared_ptr<aircraft> theAcftPt; /**< Pointer to the aircraft object */

    /**\brief Function calculates the minimum Mach number for the segment i
    *\param theAlt Aircraft altitude (m)
    *\param theEnvelopes flightEnvelopes object (load factor and speed)
    *\param ID mission segment number (-)
    *\return Minimum Mach number (-)
    */
    double findMinMach(double theAlt, std::shared_ptr<abstractFlightEnvelopes> theEnvelopes, int ID);

    /**\brief Function calculates the maximum Mach number for the segment i
    *\param theAlt Aircraft altitude (m)
    *\param theEnvelopes flightEnvelopes object (load factor and speed)
    *\param ID Mission segment number (-)
    *\return Maximum Mach number (-)
    */
    double findMaxMach(double theAlt, std::shared_ptr<abstractFlightEnvelopes> theEnvelopes, int ID);
};
}  // namespace low
#endif  // performance_assessment_SRC_TAW_DEFAULTMETHODS_SARPERFORMANCE_LOW_FIDELITY_SARPERFORMANCE_H_
