/*  Copyright (C) 2011-2022 Institute of Aerospace Systems, RWTH Aachen University - All rights reserved.
    This file is part of UNICADO.

    UNICADO is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    UNICADO is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with UNICADO.  If not, see <http://www.gnu.org/licenses/>.
*/
/**
 * @file systemsDesign.h
 * @author Ellen Seabrooke (seabrooke@ifb.uni-stuttgart.de)
 * @brief Base module for systems design
 * @version 0.1
 * @date 2024-06-27
 * 
 * @copyright Copyright (c) 2024
 * 
 */
#ifndef SYSTEMSDESIGN_SRC_SYSTEMSDESIGN_H_
#define SYSTEMSDESIGN_SRC_SYSTEMSDESIGN_H_

#include <string>
#include <vector>

//#include "systemsDesignDefines.h"
#include <moduleBasics/module.h>
#include <moduleBasics/strategySelector.h>

/**
 * \brief systemsDesign module for sizing systems
 * 
 */
class systemsDesign : public Module {
 public:
    systemsDesign(const int argc, char *argv[], const std::string& toolName, const std::string& toolVersion);
    ~systemsDesign() = default;

    void initialize() override { strategy_.initializeStrategy(); };
    void run() override { strategy_.runStrategy(); };
    void update() override { strategy_.updateStrategy();};
    void report() override { strategy_.reportStrategy();};
    void save() override { strategy_.saveStrategy(); rtIO_->saveAndCloseAcXML(); rtIO_->closeModuleConfig();};

 private:
    std::vector<std::string> route_;
    strategyaccess routing_(const std::vector<std::string>& route);
    StrategySelector strategy_;
};

#endif // SYSTEMSDESIGN_SRC_SYSTEMSDESIGN_H_
