/**
 * \file weightsAndCGs.h
 * \author Ellen Seabrooke
 * \brief Class for weight and center of gravity calculation functions
 * \version 0.1
 * \date 2024-06-27
 * 
 * @copyright Copyright (c) 2024
 * 
 */
#ifndef SYSTEMSDESIGN_SRC_WEIGHTSANDCGS_H_
#define SYSTEMSDESIGN_SRC_WEIGHTSANDCGS_H_

#include <string>
#include <vector>
#include <memory>
#include "systemsIOData.h"
#include "standardData.h"

class weightsAndCGs {
 private:
    std::shared_ptr<systemsIOData> data_; /*<-- IOData object*/

 public:
    std::vector<aircraftSystem*> System;/**vector containing all systems*/

    /** \brief Calls all functions for mass and center of gravity calculations
     * \return void
    */
    void getWeights();

    explicit weightsAndCGs(std::shared_ptr<systemsIOData> data);
    virtual ~weightsAndCGs();

 private:
    /** \brief calculates mass and cg of the propulsion group
     *
     * \return void
     *
     */
    void getPropulsionGroup();
    /** \brief calculates mass and cg of the systems group
     *
     * \return void
     *
     */
    void getSystemsGroup();
    /** \brief calculates mass and cg of the furnishings group
     *
     * \return void
     *
     */
    void getFurnishingsGroup();
    /** \brief calculates mass and cg of the operator items group
     *
     * \return void
     *
     */
    void getOperatorItems();
    /** \brief calculates mass and cg of the "not allocated" group
     *
     * \return void
     *
     */
    void getNotAllocatedSystems();

    /** \brief getter function for systems from systemArhcitecture
     *
     * \return void
     *
     */
    void getAllSystems();

    /** \brief sums up the masses of all systems excluding masses of accommodation and operator items calculated in fuselageDesing 
     * \return void
    */
    void getTotalMass();
};

#endif // SYSTEMSDESIGN_SRC_WEIGHTSANDCGS_H_
