import pytest

from basic.methodbasic import calculate_center_of_gravity, calculate_geometric_distance_by_axis, calculate_inertia_by_components
from basic.massPropertiesIO import MassPropertiesIO


def test_calculate_geometric_distance_by_axis():

    # Setup test
    reference_mp = MassPropertiesIO()
    current_mp = MassPropertiesIO()

    for ax, _ in reference_mp.center_of_gravity.items():
        reference_mp.center_of_gravity[ax] = 1.0
        current_mp.center_of_gravity[ax] = 2.0

    assert calculate_geometric_distance_by_axis(
        "j_xx", reference_mp.center_of_gravity, current_mp.center_of_gravity) == 2.0
    assert calculate_geometric_distance_by_axis(
        "j_yy", reference_mp.center_of_gravity, current_mp.center_of_gravity) == 2.0
    assert calculate_geometric_distance_by_axis(
        "j_zz", reference_mp.center_of_gravity, current_mp.center_of_gravity) == 2.0
    assert calculate_geometric_distance_by_axis(
        "j_xy", reference_mp.center_of_gravity, current_mp.center_of_gravity) == -1.0
    assert calculate_geometric_distance_by_axis(
        "j_xz", reference_mp.center_of_gravity, current_mp.center_of_gravity) == -1.0
    assert calculate_geometric_distance_by_axis(
        "j_yx", reference_mp.center_of_gravity, current_mp.center_of_gravity) == -1.0
    assert calculate_geometric_distance_by_axis(
        "j_yz", reference_mp.center_of_gravity, current_mp.center_of_gravity) == -1.0
    assert calculate_geometric_distance_by_axis(
        "j_zx", reference_mp.center_of_gravity, current_mp.center_of_gravity) == -1.0
    assert calculate_geometric_distance_by_axis(
        "j_zy", reference_mp.center_of_gravity, current_mp.center_of_gravity) == -1.0


def test_calculate_center_of_gravity():

    mp_list = [MassPropertiesIO(), MassPropertiesIO(), MassPropertiesIO()]

    for idx, mp in enumerate(mp_list):
        mp.mass = idx+0.5
        mp.center_of_gravity["x"] = idx
        mp.center_of_gravity["y"] = idx
        mp.center_of_gravity["z"] = idx

    expected_result = {"x": 0., "y": 0., "z": 0.}

    overall_mass = 0.
    for mp in mp_list:
        overall_mass += mp.mass
        expected_result["x"] += mp.mass*mp.center_of_gravity["x"]
        expected_result["y"] += mp.mass*mp.center_of_gravity["y"]
        expected_result["z"] += mp.mass*mp.center_of_gravity["z"]

    expected_result["x"] /= overall_mass
    expected_result["y"] /= overall_mass
    expected_result["z"] /= overall_mass

    assert expected_result == calculate_center_of_gravity(mp_list)


def test_calculate_inertia_by_components():
    mp_list = [MassPropertiesIO(), MassPropertiesIO()]

    for idx, mp in enumerate(mp_list):
        mp.mass = 1.0
        mp.center_of_gravity["x"] = idx
        mp.center_of_gravity["y"] = idx
        mp.center_of_gravity["z"] = idx

    for mp in mp_list:
        mp.initialize_zero_inertia()
        mp.inertia["j_xx"] = 1.0
        mp.inertia["j_yy"] = 1.0
        mp.inertia["j_zz"] = 1.0

    actual_result = calculate_inertia_by_components(mp_list)
    expected_result = {
        "j_xx": 3.0,
        "j_yy": 3.0,
        "j_zz": 3.0,
        "j_xy": -0.5,
        "j_xz": -0.5,
        "j_yx": -0.5,
        "j_yz": -0.5,
        "j_zx": -0.5,
        "j_zy": -0.5,
    }

    assert actual_result == expected_result
