/**
 * \file wingDesignMethodLow.h
 * \author Christopher Ruwisch (christopher.ruwisch@tu-berlin.de)
 * \brief Wing design method based on Matlab code from Andreas Gobbin (andreas.gobbin@tu-berlin.de)
 * \version 0.1
 * \date 2023-12-05
 *
 * @copyright Copyright (c) 2023
 *
 */
#ifndef LIB_WINGDESIGN_METHOD_LOW_H_
#define LIB_WINGDESIGN_METHOD_LOW_H_

#include <moduleBasics/modeSelector.h>

#include <tuple>
#include <vector>
namespace low {

namespace cantilever {

class WingDimensioner {
 public:
  WingDimensioner();

  double get_wing_quarter_chord_sweep(modi quarter_chord_sweep_mode, const double user_quarter_chord_sweep,
                                      const double mach_ica, const double wing_loading, const double design_altitude,
                                      const double max_thickness_to_chord_ratio, const double delta_drag_divergence,
                                      const double technology_factor_drag_divergence);
  ~WingDimensioner() = default;

  void design();

  void ruwisch_method(const double mach_ica, const double mach_mmo, const double design_altitude,
                      const std::string& airfoildatadir, std::vector<std::string>& wing_profile_names,
                      const double user_defined_taper_ratio, const double user_defined_wing_area,
                      const double maximum_takeoff_mass, const double wing_loading);

  double get_design_relative_kink_position(modi relative_kink_position_mode,
                                           const double user_defined_relative_kink_position);

  double get_design_aspect_ratio(modi aspect_ratio_mode, const double user_aspect_ratio,
                                 const double quarter_chord_sweep);
  double get_design_taper_ratio(modi taper_ratio_mode, const double user_taper_ratio, const double aspect_ratio,
                                const double quarter_chord_sweep);
  double get_design_wing_area(modi wing_area_mode, const double wing_area, const double maximum_takeoff_mass,
                              const double wing_loading);
  double get_design_dihedral(modi dihedral_mode, const std::string& wing_position, const double user_dihedral,
                             const double quarter_chord_sweep, const double mach_design);
  std::vector<std::tuple<double, double, std::string>> get_wing_profile_and_thickness(
      modi wing_profile_and_thickness,
      const std::vector<std::tuple<double, double, std::string>> user_wing_profile_and_thickess,
      const std::string& wing_profile, const double maximum_thickness_to_chord_ratio,
      const double technology_factor_airfoil, const double mach_design, const double design_altitude,
      const double quarter_chord_sweep, const double mach_drag_divergence, const double wing_loading,
      const double eta_fuselage, std::vector<double> eta_positions);

  void print_wing_data(const double installed_aspect_ratio, const double installed_wing_span,
                       const double installed_taper_ratio, const double installed_root_chord,
                       const double installed_kink_chord, const double installed_tip_chord,
                       const double installed_quarter_chord_sweep, const double installed_leading_edge_sweep_inner,
                       const double installed_trailing_edge_sweep_inner,
                       const double installed_leading_edge_sweep_outer,
                       const double installed_trailing_edge_sweep_outer, const double installed_wing_area);
  // configuration parameter
  double wing_loading{};
  double taper_ratio{};
  double maximum_aspect_ratio{};
  double wing_twist{};
  double wing_dihedral{};
  double kink_position{};

  double mean_aerodynamic_chord_to_fuselage_length{};
  double center_of_gravity_to_mean_aerodynamic_chord{};

  double buffeting_safety_factor_maneuver{1.3};
  double buffeting_safety_factor_local_lift{1.2};
  double buffeting_safety_factor_trim{1.1};

  double front_spar_positon{};
  double rear_spar_position{};
};
}  // namespace cantilever
}  // namespace low

#endif  // LIB_WINGDESIGN_METHOD_LOW_H_