#include "relativeKinkPositionMethods.h"

#include <aircraftGeometry2/processing/transform.h>

#include <cmath>
#include <functional>
#include <iostream>
#include <map>

double user_defined::relative_kink_position(const double user_relative_kink_position) {
  return user_relative_kink_position;
}

double user_defined::trailing_edge_maximum_sweep(const double user_trailing_edge_maximum_sweep) {
  return user_trailing_edge_maximum_sweep;
}

double based_on_landing_gear_track::relative_kink_position(const double initial_relative_kink_position,
                                                           const double relative_track_position_kink) {
  if (std::isnan(relative_track_position_kink)) {
    return initial_relative_kink_position;
  } else {
    return relative_track_position_kink;
  }
}

double based_on_landing_gear_track::trailing_edge_maximum_sweep(const double user_trailing_edge_maximum_sweep) {
  return user_trailing_edge_maximum_sweep;
}

double get_design_relative_kink_position(modes relative_kink_position_mode, const double user_relative_kink_position,
                                         const double track_based_initial_relative_kink,
                                         const double track_relative_kink_position) {
  std::map<modes, std::tuple<std::string, std::function<double(void)>>> relative_kink_position_selection = {
      {"mode_0", {"user_defined", [=]() { return user_defined::relative_kink_position(user_relative_kink_position); }}},
      {"mode_1", {"based_on_landing_gear_track", [=]() {
                    return based_on_landing_gear_track::relative_kink_position(track_based_initial_relative_kink,
                                                                               track_relative_kink_position);
                  }}}};
  const auto [method, relative_kink_position_method] = relative_kink_position_selection[relative_kink_position_mode];
  double relative_kink_position = relative_kink_position_method();
  std::cout << "Relative kink position [method]: " << method << "\n";
  std::cout << "Relative kink position  [value]: " << relative_kink_position << " [1]\n";
  return relative_kink_position;
}

double get_design_maximum_inner_trailing_edge_sweep(modes relative_kink_position_mode,
                                                    const double user_max_inner_trailing_edge_sweep,
                                                    const double track_based_max_inner_trailing_edge_sweep) {
  std::map<modes, std::tuple<std::string, std::function<double(void)>>> maximum_inner_trailing_edge_selection = {
      {"mode_0",
       {"user_defined",
        [=]() { return user_defined::trailing_edge_maximum_sweep(user_max_inner_trailing_edge_sweep); }}},
      {"mode_1", {"based_on_landing_gear_track", [=]() {
                    return based_on_landing_gear_track::trailing_edge_maximum_sweep(
                        track_based_max_inner_trailing_edge_sweep);
                  }}}};
  const auto [method, maximum_inner_trailing_edge_sweep_method] =
      maximum_inner_trailing_edge_selection[relative_kink_position_mode];
  double maximum_inner_trailing_edge_sweep = maximum_inner_trailing_edge_sweep_method();
  std::cout << "Maximum inner trailing edge sweep [method]: " << method << "\n";
  std::cout << "Maximum inner trailing edge sweep  [value]: "
            << maximum_inner_trailing_edge_sweep * geom2::detail::to_degrees << " [deg]\n";
  return maximum_inner_trailing_edge_sweep;
}