/**
 * \file wingDesign.cpp
 * \author Christopher Ruwisch (christopher.ruwisch@tu-berlin.de)
 * \brief Base module of wing desing
 * \version 0.1
 * \date 2023-12-05
 *
 * @copyright Copyright (c) 2023
 *
 */

#include "wingDesign.h"

#include <moduleBasics/module.h>
#include <moduleBasics/strategySelector.h>

#include <iostream>
#include <vector>

#include "cantileverWingDesignTaw.h"
#include "lib/design_methods/cantileverLow.h"
#include "lowWingDesignBwb.h"

WingDesign::WingDesign(const int argc, char *argv[], const std::string &toolName, const std::string &toolVersion)
    : Module(argc, argv, toolName, toolVersion) {
  std::string configuration = rtIO_->aircraft_configuration_type();
  std::string wing_type = "cantilever";
  
  /* Register existing strategies */
  /* tube and wing strategies */
  strategy.registerStrategy<taw::cantilever::Wing>({"tube_and_wing", "cantilever"});

  /* blended wing body strategies */
  strategy.registerStrategy<bwb::low::Wing>({"blended_wing_body", "cantilever"});
  
  /* Set desired strategy */
  strategy.setStrategy({configuration, wing_type}, rtIO_);
}
